# Util

[Kaithemautomation Index](./README.md#kaithemautomation-index) / Util

> Auto-generated documentation for [util](../../../api/util.py) module.

- [Util](#util)
  - [get_logdir](#get_logdir)
  - [get_vardir](#get_vardir)
  - [lorem](#lorem)

## get_logdir

[Show source in util.py:21](../../../api/util.py#L21)

Get the user and machine specific log directory

#### Signature

```python
def get_logdir() -> str: ...
```



## get_vardir

[Show source in util.py:26](../../../api/util.py#L26)

Get the main kaithem storage dir

#### Signature

```python
def get_vardir() -> str: ...
```



## lorem

[Show source in util.py:16](../../../api/util.py#L16)

Return a random sentence from the quotes.yaml file

#### Signature

```python
def lorem() -> str: ...
```